from distutils.core import setup
setup(
  name = 'eurobotstatus',
  packages = ['eurobotstatus'], # this must be the same as the name above
  version = '0.1',
  description = '0.1 version of eurobot status package',
  author = 'skprot',
  author_email = 'sayanprotasov@gmail.com',
  url = 'https://github.com/skprot/eurobot_status',
  download_url = 'https://github.com/skprot/eurobot_status/tarball/0.1',
  keywords = ['eurobot', 'status_commands', 'tests'],
  classifiers = [],
)